.. documentation master file, created by
   sphinx-quickstart on Sat Jan 21 19:11:14 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


===============================
1wire for Trio: Access to 1wire
===============================

This project enables you to access one or more 1wire buses asynchronously.

Prerequisites:

* Trio: https://trio.readthedocs.io

* owserver: http://owfs.org

* any OWFS-compatible hardware

=============================
 Content, indices and tables
=============================

.. toctree::
   :maxdepth: 2
   :caption: AsyncOWFS's manual:

   introduction.rst
   todo.rst
   reference.rst
   history.rst

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
